Features
========

.. tmt:autostory:: /stories/features/abort

.. tmt:autostory:: /stories/features/coverage

.. tmt:autostory:: /stories/features/feeling-safe

.. tmt:autostory:: /stories/features/prepare

.. tmt:autostory:: /stories/features/reboot

.. tmt:autostory:: /stories/features/report-log

.. tmt:autostory:: /stories/features/report-result
